dReal4: SMT Solver for Nonlinear Theories of Reals

Please visit https://github.com/dreal/dreal4.

This python package ships shared libraries for dReal (`libdreal.so`
and `_dreal_py.so`). However, you still need to install dReal
prerequisites such as IBEX and CLP in your system. To install them,
please follow the instructions.

macOS 10.14 / 10.13 / 10.12

    brew install dreal --only-dependencies

Ubuntu 18.04 / 16.04

    git clone https://github.com/dreal/dreal4 && cd dreal4
    sudo ./setup/ubuntu/`lsb_release -r -s`/install_prereqs.sh
